@@ -55,7 +55,7 @@ SEXP glm_bas(SEXP RX, SEXP RY, glmstptr *glmfamily, SEXP Roffset, SEXP Rweights,
 
 	int   i, j, l, rank=1, *pivot=INTEGER(Rpivot), conv=0;
 
-  char  trans[]="N";
+  // char  trans[]="N";
 
 	//	glmstptr *glmfamily;
 	//      glmfamily = make_glmfamily_structure(family);
