@@ -10,12 +10,13 @@ extern void gexpectations_vect(void *, void *, void *, void *, void *, void *, v
 extern void hypergeometric1F1(void *, void *, void *, void *, void *, void *);
 extern void hypergeometric2F1(void *, void *, void *, void *, void *);
 extern void logHyperGauss2F1(void *, void *, void *, void *, void *);
-extern void phi1(void *, void *, void *, void *, void *, void *, void *);
+extern void phi1(void *, void *, void *, void *, void *, void *, void *, void*, void*);
+extern void tcch(void *, void *, void *, void *, void *, void *, void *, void*);
 
 /* .Call calls */
 extern SEXP glm_deterministic(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP glm_fit(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP glm_mcmc(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP glm_mcmc(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP glm_mcmcbas(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP glm_sampleworep(SEXP,SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP deterministic(SEXP,SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
@@ -30,14 +31,15 @@ static const R_CMethodDef CEntries[] = {
   {"hypergeometric1F1",  (DL_FUNC) &hypergeometric1F1,  6},
   {"hypergeometric2F1",  (DL_FUNC) &hypergeometric2F1,  5},
   {"logHyperGauss2F1",   (DL_FUNC) &logHyperGauss2F1,   5},
-  {"phi1",               (DL_FUNC) &phi1,               7},
+  {"phi1",               (DL_FUNC) &phi1,               9},
+  {"tcch",               (DL_FUNC) &tcch,               8},
   {NULL, NULL, 0}
 };
 
 static const R_CallMethodDef CallEntries[] = {
   {"glm_deterministic", (DL_FUNC) &glm_deterministic, 11},
   {"glm_fit",           (DL_FUNC) &glm_fit,            7},
-  {"glm_mcmc",          (DL_FUNC) &glm_mcmc,          15},
+  {"glm_mcmc",          (DL_FUNC) &glm_mcmc,          16},
   {"glm_mcmcbas",       (DL_FUNC) &glm_mcmcbas,       16},
   {"glm_sampleworep",   (DL_FUNC) &glm_sampleworep,   15},
   {"mcmc_new",          (DL_FUNC) &mcmc_new,          20},
